==> ejc-doc-impl-3.0.0-20210220.090512-45-sources.jar: com/ejianc/business/doc/bean/KbmEntity.java <==
package com.ejianc.business.doc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 知识内容
 *
 * @author generator
 *
 */
 @TableName("ejc_doc_kbm")
public class KbmEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="org_id")
    private Long orgId; // 文档贡献组织Id
    @TableField(value="org_name")
    private String orgName; // 文档贡献组织名称
    @TableField(value="category_id")
    private Long categoryId; // 分类Id
    @TableField(value="category_name")
    private String categoryName; // 分类名称
    @TableField(value="title")
    private String title; // 标题
    @TableField(value="kbm_describe")
    private String kbmDescribe; // 描述说明
    @TableField(value="source")
    private String source; // 文件来源：0-企业文件，1-个人上传
    @TableField(value="scan_num")
    private java.math.BigDecimal scanNum; // 浏览量
    @TableField(value="collect_num")
    private java.math.BigDecimal collectNum; // 收藏量
    @TableField(value="bill_state")
    private Integer billState; // 单据状态0-暂存，1-已发布
    @TableField(value="category_inner_code")
    private String categoryInnerCode; // 分类内部编码
    @TableField(value="file_num")
    private java.math.BigDecimal fileNum; // 附件数
    @TableField(value="create_user_name")
    private String createUserName;
    @TableField(value="create_user_id")
    private Long createUserId; // 创建人ID

    /**
     * 文档贡献组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 文档贡献组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 文档贡献组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 文档贡献组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 分类Id
     */
    public Long getCategoryId() {
        return categoryId;
    }

    /**
     * 分类Id
     */
    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    /**
     * 分类名称
     */
    public String getCategoryName() {
        return categoryName;
    }

    /**
     * 分类名称
     */
    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    /**
     * 标题
     */
    public String getTitle() {
        return title;
    }

    /**
     * 标题
     */
    public void setTitle(String title) {
        this.title = title;
    }
    /**
     * 描述说明
     */
    public String getKbmDescribe() {
        return kbmDescribe;
    }

    /**
     * 描述说明
     */
    public void setKbmDescribe(String kbmDescribe) {
        this.kbmDescribe = kbmDescribe;
    }
    /**
     * 文件来源：0-企业文件，1-个人上传
     */
    public String getSource() {
        return source;
    }

    /**
     * 文件来源：0-企业文件，1-个人上传
     */
    public void setSource(String source) {
        this.source = source;
    }
    /**
     * 浏览量
     */
    public java.math.BigDecimal getScanNum() {
        return scanNum;
    }

    /**
     * 浏览量
     */
    public void setScanNum(java.math.BigDecimal scanNum) {
        this.scanNum = scanNum;
    }
    /**
     * 收藏量
     */
    public java.math.BigDecimal getCollectNum() {
        return collectNum;
    }

    /**
     * 收藏量
     */
    public void setCollectNum(java.math.BigDecimal collectNum) {
        this.collectNum = collectNum;
    }
    /**
     * 单据状态0-暂存，1-已发布
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态0-暂存，1-已发布
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 分类内部编码
     */
    public String getCategoryInnerCode() {
        return categoryInnerCode;
    }

    /**
     * 分类内部编码
     */
    public void setCategoryInnerCode(String categoryInnerCode) {
        this.categoryInnerCode = categoryInnerCode;
    }
    /**
     * 附件数
     */
    public java.math.BigDecimal getFileNum() {
        return fileNum;
    }

    /**
     * 附件数
     */
    public void setFileNum(java.math.BigDecimal fileNum) {
        this.fileNum = fileNum;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }
}

==> ejc-doc-impl-3.0.0-20230530.062907-108-sources.jar: com/ejianc/business/doc/bean/KbmEntity.java <==
package com.ejianc.business.doc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 知识内容
 *
 * @author generator
 *
 */
 @TableName("ejc_doc_kbm")
public class KbmEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="org_id")
    private Long orgId; // 文档贡献组织Id
    @TableField(value="org_name")
    private String orgName; // 文档贡献组织名称
    @TableField(value="category_id")
    private Long categoryId; // 分类Id
    @TableField(value="category_name")
    private String categoryName; // 分类名称
    @TableField(value="title")
    private String title; // 标题
    @TableField(value="kbm_describe")
    private String kbmDescribe; // 描述说明
    @TableField(value="source_type")
    private String sourceType; // 文件来源：0-企业文件，1-个人上传
    @TableField(value="scan_num")
    private java.math.BigDecimal scanNum; // 浏览量
    @TableField(value="collect_num")
    private java.math.BigDecimal collectNum; // 收藏量
    @TableField(value="bill_state")
    private Integer billState; // 单据状态0-暂存，1-已发布
    @TableField(value="category_inner_code")
    private String categoryInnerCode; // 分类内部编码
    @TableField(value="file_num")
    private java.math.BigDecimal fileNum; // 附件数
    @TableField(value="create_user_name")
    private String createUserName;
    @TableField(value="create_user_id")
    private Long createUserId; // 创建人ID

    /**
     * 文档贡献组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 文档贡献组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 文档贡献组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 文档贡献组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 分类Id
     */
    public Long getCategoryId() {
        return categoryId;
    }

    /**
     * 分类Id
     */
    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    /**
     * 分类名称
     */
    public String getCategoryName() {
        return categoryName;
    }

    /**
     * 分类名称
     */
    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    /**
     * 标题
     */
    public String getTitle() {
        return title;
    }

    /**
     * 标题
     */
    public void setTitle(String title) {
        this.title = title;
    }
    /**
     * 描述说明
     */
    public String getKbmDescribe() {
        return kbmDescribe;
    }

    /**
     * 描述说明
     */
    public void setKbmDescribe(String kbmDescribe) {
        this.kbmDescribe = kbmDescribe;
    }
    /**
     * 文件来源：0-企业文件，1-个人上传
     */
    public String getSourceType() {
        return sourceType;
    }

    /**
     * 文件来源：0-企业文件，1-个人上传
     */
    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    /**
     * 浏览量
     */
    public java.math.BigDecimal getScanNum() {
        return scanNum;
    }

    /**
     * 浏览量
     */
    public void setScanNum(java.math.BigDecimal scanNum) {
        this.scanNum = scanNum;
    }
    /**
     * 收藏量
     */
    public java.math.BigDecimal getCollectNum() {
        return collectNum;
    }

    /**
     * 收藏量
     */
    public void setCollectNum(java.math.BigDecimal collectNum) {
        this.collectNum = collectNum;
    }
    /**
     * 单据状态0-暂存，1-已发布
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态0-暂存，1-已发布
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 分类内部编码
     */
    public String getCategoryInnerCode() {
        return categoryInnerCode;
    }

    /**
     * 分类内部编码
     */
    public void setCategoryInnerCode(String categoryInnerCode) {
        this.categoryInnerCode = categoryInnerCode;
    }
    /**
     * 附件数
     */
    public java.math.BigDecimal getFileNum() {
        return fileNum;
    }

    /**
     * 附件数
     */
    public void setFileNum(java.math.BigDecimal fileNum) {
        this.fileNum = fileNum;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }
}
